@@ -38,7 +38,6 @@ package net.sourceforge.plantuml;
 import java.util.Collection;
 import java.util.Map;
 
-import net.sourceforge.plantuml.api.ThemeStyle;
 import net.sourceforge.plantuml.cucadiagram.Rankdir;
 import net.sourceforge.plantuml.cucadiagram.Stereotype;
 import net.sourceforge.plantuml.cucadiagram.dot.DotSplines;
@@ -56,7 +55,6 @@ import net.sourceforge.plantuml.svek.PackageStyle;
 import net.sourceforge.plantuml.svg.LengthAdjust;
 import net.sourceforge.plantuml.ugraphic.UFont;
 import net.sourceforge.plantuml.ugraphic.UStroke;
-import net.sourceforge.plantuml.ugraphic.color.ColorMapper;
 import net.sourceforge.plantuml.ugraphic.color.HColor;
 import net.sourceforge.plantuml.ugraphic.color.HColorSet;
 import net.sourceforge.plantuml.ugraphic.color.NoSuchColorException;
@@ -125,11 +123,6 @@ public class SkinParamDelegator implements ISkinParam {
 		return skinParam.getHorizontalAlignment(param, arrowDirection, isReverseDefine, overrideDefault);
 	}
 
-	@Override
-	public ColorMapper getColorMapper() {
-		return skinParam.getColorMapper();
-	}
-
 	@Override
 	public boolean shadowing(Stereotype stereotype) {
 		return skinParam.shadowing(stereotype);
@@ -386,7 +379,7 @@ public class SkinParamDelegator implements ISkinParam {
 	}
 
 	@Override
-	public void copyAllFrom(ISkinSimple other) {
+	public void copyAllFrom(Map<String, String> other) {
 		skinParam.copyAllFrom(other);
 	}
 
@@ -450,14 +443,4 @@ public class SkinParamDelegator implements ISkinParam {
 		return skinParam.getlengthAdjust();
 	}
 
-//	@Override
-//	public void assumeTransparent(ThemeStyle style) {
-//		skinParam.assumeTransparent(style);
-//	}
-
-	@Override
-	public ThemeStyle getThemeStyle() {
-		return skinParam.getThemeStyle();
-	}
-
 }
