@@ -37,12 +37,9 @@ package net.sourceforge.plantuml;
 
 import java.util.Map;
 
-import net.sourceforge.plantuml.api.ThemeStyle;
 import net.sourceforge.plantuml.creole.Parser;
 import net.sourceforge.plantuml.sprite.Sprite;
 import net.sourceforge.plantuml.sprite.SpriteImage;
-import net.sourceforge.plantuml.ugraphic.color.ColorMapper;
-import net.sourceforge.plantuml.ugraphic.color.ColorMapperIdentity;
 import net.sourceforge.plantuml.ugraphic.color.HColorSet;
 
 public class SpriteContainerEmpty implements SpriteContainer, ISkinSimple {
@@ -83,11 +80,7 @@ public class SpriteContainerEmpty implements SpriteContainer, ISkinSimple {
 		return LineBreakStrategy.NONE;
 	}
 
-	public ColorMapper getColorMapper() {
-		return new ColorMapperIdentity();
-	}
-
-	public void copyAllFrom(ISkinSimple other) {
+	public void copyAllFrom(Map<String, String> other) {
 		throw new UnsupportedOperationException();
 	}
 
@@ -103,8 +96,4 @@ public class SpriteContainerEmpty implements SpriteContainer, ISkinSimple {
 		return s;
 	}
 
-	public ThemeStyle getThemeStyle() {
-		return ThemeStyle.LIGHT_REGULAR;
-	}
-
 }
\ No newline at end of file
