@@ -38,6 +38,7 @@ package net.sourceforge.plantuml.activitydiagram3.command;
 import net.sourceforge.plantuml.LineLocation;
 import net.sourceforge.plantuml.StringUtils;
 import net.sourceforge.plantuml.activitydiagram3.ActivityDiagram3;
+import net.sourceforge.plantuml.activitydiagram3.ftile.vcompact.FtileGroup;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
 import net.sourceforge.plantuml.command.SingleLineCommand2;
 import net.sourceforge.plantuml.command.regex.IRegex;
@@ -53,9 +54,7 @@ import net.sourceforge.plantuml.graphic.color.ColorParser;
 import net.sourceforge.plantuml.graphic.color.ColorType;
 import net.sourceforge.plantuml.graphic.color.Colors;
 import net.sourceforge.plantuml.style.PName;
-import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
-import net.sourceforge.plantuml.style.StyleSignatureBasic;
 import net.sourceforge.plantuml.ugraphic.color.HColor;
 import net.sourceforge.plantuml.ugraphic.color.HColors;
 import net.sourceforge.plantuml.ugraphic.color.NoSuchColorException;
@@ -68,13 +67,13 @@ public class CommandPartition3 extends SingleLineCommand2<ActivityDiagram3> {
 
 	static IRegex getRegexConcat() {
 		return RegexConcat.build(CommandPartition3.class.getName(), RegexLeaf.start(), //
-				new RegexLeaf("TYPE", "(partition|package|rectangle|card)"), //
+				new RegexLeaf("TYPE", "(partition|package|rectangle|card|group)"), //
 				RegexLeaf.spaceOneOrMore(), //
 				new RegexOptional(//
 						new RegexConcat( //
 								color("BACK1").getRegex(), //
 								RegexLeaf.spaceOneOrMore())), //
-				new RegexLeaf("NAME", "([%g][^%g]+[%g]|\\S+)"), //
+				new RegexLeaf("NAME", "([%g][^%g]+[%g]|.*?)"), //
 				new RegexOptional(//
 						new RegexConcat( //
 								RegexLeaf.spaceOneOrMore(), //
@@ -87,8 +86,8 @@ public class CommandPartition3 extends SingleLineCommand2<ActivityDiagram3> {
 	}
 
 	private USymbol getUSymbol(String type) {
-		if ("card".equalsIgnoreCase(type))
-			return USymbols.CARD;
+		if ("partition".equalsIgnoreCase(type))
+			return USymbols.PARTITION;
 
 		if ("package".equalsIgnoreCase(type))
 			return USymbols.PACKAGE;
@@ -96,27 +95,27 @@ public class CommandPartition3 extends SingleLineCommand2<ActivityDiagram3> {
 		if ("rectangle".equalsIgnoreCase(type))
 			return USymbols.RECTANGLE;
 
-		return USymbols.FRAME;
+		if ("card".equalsIgnoreCase(type))
+			return USymbols.CARD;
+
+		if ("group".equalsIgnoreCase(type))
+			return USymbols.GROUP;
+
+		throw new IllegalArgumentException();
 	}
 
 	private static ColorParser color(String id) {
 		return ColorParser.simpleColor(ColorType.BACK, id);
 	}
 
-	private StyleSignatureBasic getDefaultStyleDefinitionPartition(USymbol symbol) {
-		if (symbol == USymbols.RECTANGLE)
-			return StyleSignatureBasic.of(SName.root, SName.element, SName.activityDiagram, SName.rectangle);
-		return StyleSignatureBasic.of(SName.root, SName.element, SName.activityDiagram, SName.partition);
-	}
-
 	@Override
 	protected CommandExecutionResult executeArg(ActivityDiagram3 diagram, LineLocation location, RegexResult arg)
 			throws NoSuchColorException {
 		final String partitionTitle = StringUtils.eventuallyRemoveStartingAndEndingDoubleQuote(arg.get("NAME", 0));
 
 		final String b1 = arg.get("BACK1", 0);
-		final Colors colors = color(b1 == null ? "BACK2" : "BACK1").getColor(diagram.getSkinParam().getThemeStyle(),
-				arg, diagram.getSkinParam().getIHtmlColorSet());
+		final Colors colors = color(b1 == null ? "BACK2" : "BACK1").getColor(arg,
+				diagram.getSkinParam().getIHtmlColorSet());
 
 		final USymbol symbol = getUSymbol(arg.get("TYPE", 0));
 		final String stereo = arg.get("STEREO", 0);
@@ -124,14 +123,12 @@ public class CommandPartition3 extends SingleLineCommand2<ActivityDiagram3> {
 
 		// Warning : titleColor unused in FTileGroupW
 
-		final Style stylePartition = getDefaultStyleDefinitionPartition(symbol).withTOBECHANGED(stereotype)
+		final Style stylePartition = FtileGroup.getStyleSignature(symbol).withTOBECHANGED(stereotype)
 				.getMergedStyle(diagram.getSkinParam().getCurrentStyleBuilder());
-		final HColor borderColor = stylePartition.value(PName.LineColor).asColor(diagram.getSkinParam().getThemeStyle(),
-				diagram.getSkinParam().getIHtmlColorSet());
+		final HColor borderColor = stylePartition.value(PName.LineColor).asColor(diagram.getSkinParam().getIHtmlColorSet());
 		HColor backColor = colors.getColor(ColorType.BACK);
 		if (backColor == null)
-			backColor = stylePartition.value(PName.BackGroundColor).asColor(diagram.getSkinParam().getThemeStyle(),
-					diagram.getSkinParam().getIHtmlColorSet());
+			backColor = stylePartition.value(PName.BackGroundColor).asColor(diagram.getSkinParam().getIHtmlColorSet());
 
 		final HColor titleColor = HColors.BLUE;// stylePartition.value(PName.FontColor).asColor(diagram.getSkinParam().getIHtmlColorSet());
 		final double roundCorner = stylePartition.value(PName.RoundCorner).asDouble();
