@@ -41,12 +41,11 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
 
-import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.activitydiagram3.ftile.AbstractFtile;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Ftile;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileGeometry;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Swimlane;
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
@@ -96,7 +95,7 @@ class FtileSplit1 extends AbstractFtile {
 		double height = 0;
 		double width = 0;
 		for (Ftile ftile : forks) {
-			final Dimension2D dim = ftile.calculateDimension(stringBounder);
+			final XDimension2D dim = ftile.calculateDimension(stringBounder);
 			if (dim.getWidth() > width) {
 				width = dim.getWidth();
 			}
@@ -104,12 +103,12 @@ class FtileSplit1 extends AbstractFtile {
 				height = dim.getHeight();
 			}
 		}
-		final Dimension2D dimTotal = new Dimension2DDouble(width, height);
+		final XDimension2D dimTotal = new XDimension2D(width, height);
 		return new FtileGeometry(dimTotal, dimTotal.getWidth() / 2, 0, dimTotal.getHeight());
 	}
 
 	public UTranslate getTranslateFor(Ftile searched, StringBounder stringBounder) {
-		final Dimension2D dim = searched.calculateDimension(stringBounder);
+		final XDimension2D dim = searched.calculateDimension(stringBounder);
 		final double xpos = calculateDimension(stringBounder).getWidth() - dim.getWidth();
 		return UTranslate.dx(xpos / 2);
 	}
