@@ -39,7 +39,6 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.Set;
 
-import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.LineBreakStrategy;
 import net.sourceforge.plantuml.SkinParamColors;
@@ -49,7 +48,7 @@ import net.sourceforge.plantuml.activitydiagram3.ftile.BoxStyle;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Ftile;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileGeometry;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Swimlane;
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
 import net.sourceforge.plantuml.creole.CreoleMode;
 import net.sourceforge.plantuml.creole.Parser;
 import net.sourceforge.plantuml.creole.Sheet;
@@ -129,7 +128,7 @@ public class FtileBox extends AbstractFtile {
 		}
 
 		public double getEndingX(StringBounder stringBounder, double y) {
-			final Dimension2D dim = calculateDimension(stringBounder);
+			final XDimension2D dim = calculateDimension(stringBounder);
 			return dim.getWidth() - padding.getRight();
 		}
 
@@ -151,16 +150,16 @@ public class FtileBox extends AbstractFtile {
 		this.swimlane = swimlane;
 
 		this.inRendering = LinkRendering
-				.create(Rainbow.build(styleArrow, getIHtmlColorSet(), skinParam.getThemeStyle()));
+				.create(Rainbow.build(styleArrow, getIHtmlColorSet()));
 		Colors specBack = null;
 		if (skinParam instanceof SkinParamColors)
 			specBack = ((SkinParamColors) skinParam).getColors();
 
 		style = style.eventuallyOverride(specBack);
-		this.borderColor = style.value(PName.LineColor).asColor(skinParam.getThemeStyle(), getIHtmlColorSet());
-		this.backColor = style.value(PName.BackGroundColor).asColor(skinParam.getThemeStyle(), getIHtmlColorSet());
+		this.borderColor = style.value(PName.LineColor).asColor(getIHtmlColorSet());
+		this.backColor = style.value(PName.BackGroundColor).asColor(getIHtmlColorSet());
 
-		final FontConfiguration fc = style.getFontConfiguration(skinParam.getThemeStyle(), getIHtmlColorSet());
+		final FontConfiguration fc = style.getFontConfiguration(getIHtmlColorSet());
 
 		this.horizontalAlignment = style.getHorizontalAlignment();
 		this.padding = style.getPadding();
@@ -188,7 +187,7 @@ public class FtileBox extends AbstractFtile {
 	}
 
 	public void drawU(UGraphic ug) {
-		final Dimension2D dimTotal = calculateDimension(ug.getStringBounder());
+		final XDimension2D dimTotal = calculateDimension(ug.getStringBounder());
 		final double widthTotal = dimTotal.getWidth();
 		final double heightTotal = dimTotal.getHeight();
 		final UDrawable shape = boxStyle.getUDrawable(widthTotal, heightTotal, shadowing, roundCorner);
@@ -211,21 +210,21 @@ public class FtileBox extends AbstractFtile {
 		if (horizontalAlignment == HorizontalAlignment.LEFT) {
 			tb.drawU(ug.apply(new UTranslate(padding.getLeft(), padding.getTop())));
 		} else if (horizontalAlignment == HorizontalAlignment.RIGHT) {
-			final Dimension2D dimTb = tb.calculateDimension(ug.getStringBounder());
+			final XDimension2D dimTb = tb.calculateDimension(ug.getStringBounder());
 			tb.drawU(ug.apply(
 					new UTranslate(dimTotal.getWidth() - dimTb.getWidth() - padding.getRight(), padding.getBottom())));
 		} else if (horizontalAlignment == HorizontalAlignment.CENTER) {
-			final Dimension2D dimTb = tb.calculateDimension(ug.getStringBounder());
+			final XDimension2D dimTb = tb.calculateDimension(ug.getStringBounder());
 			tb.drawU(ug.apply(new UTranslate((dimTotal.getWidth() - dimTb.getWidth()) / 2, padding.getBottom())));
 		}
 	}
 
 	@Override
 	protected FtileGeometry calculateDimensionFtile(StringBounder stringBounder) {
-		Dimension2D dimRaw = tb.calculateDimension(stringBounder);
-		dimRaw = Dimension2DDouble.delta(dimRaw, padding.getLeft() + padding.getRight(),
+		XDimension2D dimRaw = tb.calculateDimension(stringBounder);
+		dimRaw = XDimension2D.delta(dimRaw, padding.getLeft() + padding.getRight(),
 				padding.getBottom() + padding.getTop());
-		dimRaw = Dimension2DDouble.atLeast(dimRaw, minimumWidth, 0);
+		dimRaw = XDimension2D.atLeast(dimRaw, minimumWidth, 0);
 		return new FtileGeometry(dimRaw.getWidth() + boxStyle.getShield(), dimRaw.getHeight(), dimRaw.getWidth() / 2, 0,
 				dimRaw.getHeight());
 	}
