@@ -38,6 +38,7 @@ package net.sourceforge.plantuml.asciiart;
 import net.sourceforge.plantuml.FileFormat;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.cucadiagram.Display;
+import net.sourceforge.plantuml.graphic.color.Colors;
 import net.sourceforge.plantuml.sequencediagram.NotePosition;
 import net.sourceforge.plantuml.skin.ArrowComponent;
 import net.sourceforge.plantuml.skin.ArrowConfiguration;
@@ -61,104 +62,103 @@ public class TextSkin extends Rose {
 			Display stringsToDisplay) {
 		if (config.getArrowDirection() == ArrowDirection.LEFT_TO_RIGHT_NORMAL
 				|| config.getArrowDirection() == ArrowDirection.RIGHT_TO_LEFT_REVERSE
-				|| config.getArrowDirection() == ArrowDirection.BOTH_DIRECTION) {
+				|| config.getArrowDirection() == ArrowDirection.BOTH_DIRECTION)
 			return new ComponentTextArrow(ComponentType.ARROW, config, stringsToDisplay, fileFormat,
 					param.maxAsciiMessageLength());
-		}
-		if (config.isSelfArrow()) {
+
+		if (config.isSelfArrow())
 			return new ComponentTextSelfArrow(ComponentType.ARROW, config, stringsToDisplay, fileFormat);
-		}
+
 		throw new UnsupportedOperationException();
 	}
 
 	@Override
 	public Component createComponentNote(Style[] styles, ComponentType type, ISkinParam param, Display stringsToDisplay,
-			NotePosition notePosition) {
-		if (type == ComponentType.NOTE || type == ComponentType.NOTE_BOX) {
+			Colors colors, NotePosition notePosition) {
+		if (type == ComponentType.NOTE || type == ComponentType.NOTE_BOX)
 			return new ComponentTextNote(type, stringsToDisplay, fileFormat);
-		}
+
 		throw new UnsupportedOperationException(type.toString());
 	}
 
 	@Override
-	public Component createComponentNote(Style[] styles, ComponentType type, ISkinParam param,
-			Display stringsToDisplay) {
-		return createComponentNote(styles, type, param, stringsToDisplay, null);
+	public Component createComponentNote(Style[] styles, ComponentType type, ISkinParam param, Display stringsToDisplay,
+			Colors colors) {
+		return createComponentNote(styles, type, param, stringsToDisplay, colors, null);
 	}
 
 	@Override
 	public Component createComponent(Style style[], ComponentType type, ArrowConfiguration config, ISkinParam param,
 			Display stringsToDisplay) {
-		if (type == ComponentType.ACTOR_HEAD || type == ComponentType.ACTOR_TAIL) {
+		if (type == ComponentType.ACTOR_HEAD || type == ComponentType.ACTOR_TAIL)
 			return new ComponentTextActor(type, stringsToDisplay, fileFormat,
 					fileFormat == FileFormat.UTXT ? AsciiShape.STICKMAN_UNICODE : AsciiShape.STICKMAN);
-		}
-		if (type == ComponentType.BOUNDARY_HEAD || type == ComponentType.BOUNDARY_TAIL) {
+
+		if (type == ComponentType.BOUNDARY_HEAD || type == ComponentType.BOUNDARY_TAIL)
 			return new ComponentTextShape(type, stringsToDisplay, AsciiShape.BOUNDARY);
-		}
-		if (type == ComponentType.DATABASE_HEAD || type == ComponentType.DATABASE_TAIL) {
+
+		if (type == ComponentType.DATABASE_HEAD || type == ComponentType.DATABASE_TAIL)
 			return new ComponentTextShape(type, stringsToDisplay, AsciiShape.DATABASE);
-		}
-		if (type.name().endsWith("_HEAD") || type.name().endsWith("_TAIL")) {
+
+		if (type.name().endsWith("_HEAD") || type.name().endsWith("_TAIL"))
 			return new ComponentTextParticipant(type, stringsToDisplay, fileFormat);
-		}
+
 		if (type.isArrow() && (config.getArrowDirection() == ArrowDirection.LEFT_TO_RIGHT_NORMAL
 				|| config.getArrowDirection() == ArrowDirection.RIGHT_TO_LEFT_REVERSE
-				|| config.getArrowDirection() == ArrowDirection.BOTH_DIRECTION)) {
+				|| config.getArrowDirection() == ArrowDirection.BOTH_DIRECTION))
 			return new ComponentTextArrow(type, config, stringsToDisplay, fileFormat, param.maxAsciiMessageLength());
-		}
-		if (type.isArrow() && config.isSelfArrow()) {
+
+		if (type.isArrow() && config.isSelfArrow())
 			return new ComponentTextSelfArrow(type, config, stringsToDisplay, fileFormat);
-		}
-		if (type == ComponentType.PARTICIPANT_LINE) {
+
+		if (type == ComponentType.PARTICIPANT_LINE)
 			return new ComponentTextLine(type, fileFormat);
-		}
-		if (type == ComponentType.CONTINUE_LINE) {
+
+		if (type == ComponentType.CONTINUE_LINE)
 			return new ComponentTextLine(type, fileFormat);
-		}
-		if (type == ComponentType.DELAY_LINE) {
+
+		if (type == ComponentType.DELAY_LINE)
 			return new ComponentTextLine(type, fileFormat);
-		}
-		if (type == ComponentType.ALIVE_BOX_CLOSE_CLOSE) {
+
+		if (type == ComponentType.ALIVE_BOX_CLOSE_CLOSE)
 			return new ComponentTextActiveLine(fileFormat);
-		}
-		if (type == ComponentType.ALIVE_BOX_CLOSE_OPEN) {
+
+		if (type == ComponentType.ALIVE_BOX_CLOSE_OPEN)
 			return new ComponentTextActiveLine(fileFormat);
-		}
-		if (type == ComponentType.ALIVE_BOX_OPEN_CLOSE) {
+
+		if (type == ComponentType.ALIVE_BOX_OPEN_CLOSE)
 			return new ComponentTextActiveLine(fileFormat);
-		}
-		if (type == ComponentType.ALIVE_BOX_OPEN_OPEN) {
+
+		if (type == ComponentType.ALIVE_BOX_OPEN_OPEN)
 			return new ComponentTextActiveLine(fileFormat);
-		}
-		if (type == ComponentType.DIVIDER) {
+
+		if (type == ComponentType.DIVIDER)
 			return new ComponentTextDivider(type, stringsToDisplay, fileFormat);
-		}
-		if (type == ComponentType.GROUPING_HEADER) {
+
+		if (type == ComponentType.GROUPING_HEADER)
 			return new ComponentTextGroupingHeader(type, stringsToDisplay, fileFormat);
-		}
-		if (type == ComponentType.GROUPING_SPACE) {
+
+		if (type == ComponentType.GROUPING_SPACE)
 			return new ComponentRoseGroupingSpace(1);
-		}
-		if (type == ComponentType.GROUPING_ELSE) {
+
+		if (type == ComponentType.GROUPING_ELSE)
 			return new ComponentTextGroupingElse(type, stringsToDisplay, fileFormat);
-		}
-		if (type == ComponentType.DELAY_TEXT) {
+
+		if (type == ComponentType.DELAY_TEXT)
 			return new ComponentTextDelay(type, stringsToDisplay, fileFormat);
-		}
-		if (type == ComponentType.DESTROY) {
+
+		if (type == ComponentType.DESTROY)
 			return new ComponentTextDestroy();
-		}
-		if (type == ComponentType.REFERENCE) {
+
+		if (type == ComponentType.REFERENCE)
 			return new ComponentTextReference(stringsToDisplay, fileFormat);
-		}
+
 		throw new UnsupportedOperationException(type.toString());
 	}
-	
+
 	@Override
 	public Component createComponentNewPage(ISkinParam param) {
 		return new ComponentTextNewpage(fileFormat);
 	}
 
-
 }
