@@ -36,6 +36,6 @@
 package net.sourceforge.plantuml.creole;
 
 public enum CreoleMode {
-	FULL, SIMPLE_LINE, NO_CREOLE;
+	FULL, SIMPLE_LINE, NO_CREOLE, FULL_BUT_UNDERSCORE;
 
 }
