@@ -36,7 +36,7 @@
 package net.sourceforge.plantuml.cucadiagram.dot;
 
 public interface GraphvizVersion {
-	public boolean useShield();
+	public boolean useShieldForQuantifier();
 
 	public boolean useProtectionWhenThereALinkFromOrToGroup();
 
