@@ -35,9 +35,9 @@
  */
 package net.sourceforge.plantuml.eggs;
 
-import net.sourceforge.plantuml.ISkinSimple;
+import java.util.Map;
+
 import net.sourceforge.plantuml.api.PSystemFactory;
-import net.sourceforge.plantuml.api.ThemeStyle;
 import net.sourceforge.plantuml.core.Diagram;
 import net.sourceforge.plantuml.core.DiagramType;
 import net.sourceforge.plantuml.core.UmlSource;
@@ -46,7 +46,7 @@ import net.sourceforge.plantuml.graphic.GraphicPosition;
 public class PSystemWelcomeFactory implements PSystemFactory {
 
 	@Override
-	public Diagram createSystem(ThemeStyle style, UmlSource source, ISkinSimple skinParam) {
+	public Diagram createSystem(UmlSource source, Map<String, String> skinParam) {
 		if (source.getTotalLineCount() == 2)
 			return new PSystemWelcome(source, GraphicPosition.BACKGROUND_CORNER_BOTTOM_RIGHT);
 
