@@ -38,8 +38,7 @@ package net.sourceforge.plantuml.graphic;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UStroke;
 import net.sourceforge.plantuml.ugraphic.color.HColor;
-import net.sourceforge.plantuml.ugraphic.color.HColorBackground;
-import net.sourceforge.plantuml.ugraphic.color.HColorNone;
+import net.sourceforge.plantuml.ugraphic.color.HColors;
 
 public class SymbolContext {
 
@@ -73,11 +72,11 @@ public class SymbolContext {
 
 	public UGraphic applyColors(UGraphic ug) {
 		if (foreColor == null)
-			ug = ug.apply(new HColorNone());
+			ug = ug.apply(HColors.none());
 		else
 			ug = ug.apply(foreColor);
 		if (backColor == null)
-			ug = ug.apply(new HColorNone().bg());
+			ug = ug.apply(HColors.none().bg());
 		else
 			ug = ug.apply(backColor.bg());
 
@@ -88,14 +87,6 @@ public class SymbolContext {
 		return ug.apply(stroke);
 	}
 
-	public SymbolContext transparentBackColorToNull() {
-		if (backColor instanceof HColorBackground) {
-			return new SymbolContext(((HColorBackground) backColor).getNull(), foreColor, stroke, deltaShadow,
-					roundCorner, diagonalCorner);
-		}
-		return this;
-	}
-
 	public SymbolContext(HColor backColor, HColor foreColor) {
 		this(backColor, foreColor, new UStroke(), 0, 0, 0);
 	}
