@@ -2,15 +2,15 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2020, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
- * 
+ *
  * If you like this project or if you find it useful, you can support us at:
- * 
+ *
  * http://plantuml.com/patreon (only 1$ per month!)
  * http://plantuml.com/paypal
- * 
+ *
  * This file is part of PlantUML.
  *
  * PlantUML is free software; you can redistribute it and/or modify it
@@ -30,11 +30,15 @@
  *
  *
  * Original Author:  Arnaud Roques
- * 
+ *
  *
  */
 package net.sourceforge.plantuml.graphic;
 
+import java.io.IOException;
+import java.io.OutputStream;
+import java.util.Map;
+
 import net.sourceforge.plantuml.Url;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UGroupType;
@@ -43,9 +47,6 @@ import net.sourceforge.plantuml.ugraphic.UShape;
 import net.sourceforge.plantuml.ugraphic.color.ColorMapper;
 import net.sourceforge.plantuml.ugraphic.color.HColor;
 
-import java.io.IOException;
-import java.io.OutputStream;
-
 public abstract class UGraphicDelegator implements UGraphic {
 
 	final private UGraphic ug;
@@ -78,7 +79,7 @@ public abstract class UGraphicDelegator implements UGraphic {
 	public ColorMapper getColorMapper() {
 		return ug.getColorMapper();
 	}
-	
+
 	@Override
 	public void startUrl(Url url) {
 		ug.startUrl(url);
@@ -89,8 +90,8 @@ public abstract class UGraphicDelegator implements UGraphic {
 		ug.closeUrl();
 	}
 
-	public void startGroup(UGroupType type, String ident) {
-		ug.startGroup(type, ident);
+	public void startGroup(Map<UGroupType, String> typeIdents) {
+		ug.startGroup(typeIdents);
 	}
 
 	public void closeGroup() {
