@@ -35,10 +35,8 @@
  */
 package net.sourceforge.plantuml.graphic;
 
-import java.awt.geom.Point2D;
-
-import net.sourceforge.plantuml.Dimension2DDouble;
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.ugraphic.Shadowable;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
@@ -72,13 +70,13 @@ class USymbolFile extends USymbol {
 			final UPath path = new UPath();
 			path.moveTo(0, roundCorner / 2);
 			path.lineTo(0, height - roundCorner / 2);
-			path.arcTo(new Point2D.Double(roundCorner / 2, height), roundCorner / 2, 0, 0);
+			path.arcTo(new XPoint2D(roundCorner / 2, height), roundCorner / 2, 0, 0);
 			path.lineTo(width - roundCorner / 2, height);
-			path.arcTo(new Point2D.Double(width, height - roundCorner / 2), roundCorner / 2, 0, 0);
+			path.arcTo(new XPoint2D(width, height - roundCorner / 2), roundCorner / 2, 0, 0);
 			path.lineTo(width, cornersize);
 			path.lineTo(width - cornersize, 0);
 			path.lineTo(roundCorner / 2, 0);
-			path.arcTo(new Point2D.Double(0, roundCorner / 2), roundCorner / 2, 0, 0);
+			path.arcTo(new XPoint2D(0, roundCorner / 2), roundCorner / 2, 0, 0);
 			out = path;
 		}
 
@@ -91,7 +89,7 @@ class USymbolFile extends USymbol {
 			path.lineTo(width - cornersize, cornersize);
 		} else {
 			path.lineTo(width - cornersize, cornersize - roundCorner / 2);
-			path.arcTo(new Point2D.Double(width - cornersize + roundCorner / 2, cornersize), roundCorner / 2, 0, 0);
+			path.arcTo(new XPoint2D(width - cornersize + roundCorner / 2, cornersize), roundCorner / 2, 0, 0);
 		}
 		path.lineTo(width, cornersize);
 		ug.draw(path);
@@ -107,7 +105,7 @@ class USymbolFile extends USymbol {
 		return new AbstractTextBlock() {
 
 			public void drawU(UGraphic ug) {
-				final Dimension2D dim = calculateDimension(ug.getStringBounder());
+				final XDimension2D dim = calculateDimension(ug.getStringBounder());
 				ug = UGraphicStencil.create(ug, dim);
 				ug = symbolContext.apply(ug);
 				drawFile(ug, dim.getWidth(), dim.getHeight(), symbolContext.getDeltaShadow(),
@@ -117,10 +115,10 @@ class USymbolFile extends USymbol {
 				tb.drawU(ug.apply(new UTranslate(margin.getX1(), margin.getY1())));
 			}
 
-			public Dimension2D calculateDimension(StringBounder stringBounder) {
-				final Dimension2D dimLabel = label.calculateDimension(stringBounder);
-				final Dimension2D dimStereo = stereotype.calculateDimension(stringBounder);
-				return getMargin().addDimension(Dimension2DDouble.mergeTB(dimStereo, dimLabel));
+			public XDimension2D calculateDimension(StringBounder stringBounder) {
+				final XDimension2D dimLabel = label.calculateDimension(stringBounder);
+				final XDimension2D dimStereo = stereotype.calculateDimension(stringBounder);
+				return getMargin().addDimension(XDimension2D.mergeTB(dimStereo, dimLabel));
 			}
 		};
 	}
@@ -132,11 +130,11 @@ class USymbolFile extends USymbol {
 		return new AbstractTextBlock() {
 
 			public void drawU(UGraphic ug) {
-				final Dimension2D dim = calculateDimension(ug.getStringBounder());
+				final XDimension2D dim = calculateDimension(ug.getStringBounder());
 				ug = symbolContext.apply(ug);
 				drawFile(ug, dim.getWidth(), dim.getHeight(), symbolContext.getDeltaShadow(),
 						symbolContext.getRoundCorner());
-				final Dimension2D dimStereo = stereotype.calculateDimension(ug.getStringBounder());
+				final XDimension2D dimStereo = stereotype.calculateDimension(ug.getStringBounder());
 				final double posStereoX;
 				final double posStereoY;
 				if (stereotypeAlignement == HorizontalAlignment.RIGHT) {
@@ -147,13 +145,13 @@ class USymbolFile extends USymbol {
 					posStereoY = 2;
 				}
 				stereotype.drawU(ug.apply(new UTranslate(posStereoX, posStereoY)));
-				final Dimension2D dimTitle = title.calculateDimension(ug.getStringBounder());
+				final XDimension2D dimTitle = title.calculateDimension(ug.getStringBounder());
 				final double posTitle = (width - dimTitle.getWidth()) / 2;
 				title.drawU(ug.apply(new UTranslate(posTitle, 2 + dimStereo.getHeight())));
 			}
 
-			public Dimension2D calculateDimension(StringBounder stringBounder) {
-				return new Dimension2DDouble(width, height);
+			public XDimension2D calculateDimension(StringBounder stringBounder) {
+				return new XDimension2D(width, height);
 			}
 		};
 	}
