@@ -35,14 +35,13 @@
  */
 package net.sourceforge.plantuml.jsondiagram;
 
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 
-import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.LineBreakStrategy;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
 import net.sourceforge.plantuml.creole.CreoleMode;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.graphic.AbstractTextBlock;
@@ -104,8 +103,7 @@ public class TextBlockJson extends AbstractTextBlock implements TextBlockBackcol
 	}
 
 	private HColor getBackColor() {
-		return styleNodeHightlight.value(PName.BackGroundColor).asColor(skinParam.getThemeStyle(),
-				skinParam.getIHtmlColorSet());
+		return styleNodeHightlight.value(PName.BackGroundColor).asColor(skinParam.getIHtmlColorSet());
 	}
 
 	TextBlockJson(ISkinParam skinParam, JsonValue root, List<String> allHighlighteds, Style styleNode,
@@ -231,8 +229,8 @@ public class TextBlockJson extends AbstractTextBlock implements TextBlockBackcol
 		return Collections.unmodifiableList(result);
 	}
 
-	public Dimension2D calculateDimension(StringBounder stringBounder) {
-		return new Dimension2DDouble(getWidthColA(stringBounder) + getWidthColB(stringBounder),
+	public XDimension2D calculateDimension(StringBounder stringBounder) {
+		return new XDimension2D(getWidthColA(stringBounder) + getWidthColB(stringBounder),
 				getTotalHeight(stringBounder));
 	}
 
@@ -256,14 +254,13 @@ public class TextBlockJson extends AbstractTextBlock implements TextBlockBackcol
 	public void drawU(final UGraphic ug) {
 		final StringBounder stringBounder = ug.getStringBounder();
 
-		final Dimension2D fullDim = calculateDimension(stringBounder);
+		final XDimension2D fullDim = calculateDimension(stringBounder);
 		double trueWidth = Math.max(fullDim.getWidth(), totalWidth);
 		final double widthColA = getWidthColA(stringBounder);
 		final double widthColB = getWidthColB(stringBounder);
 
 		double y = 0;
-		final UGraphic ugNode = styleNode.applyStrokeAndLineColor(ug, skinParam.getIHtmlColorSet(),
-				skinParam.getThemeStyle());
+		final UGraphic ugNode = styleNode.applyStrokeAndLineColor(ug, skinParam.getIHtmlColorSet());
 		for (Line line : lines) {
 			final double heightOfRow = line.getHeightOfRow(stringBounder);
 			y += heightOfRow;
@@ -275,14 +272,12 @@ public class TextBlockJson extends AbstractTextBlock implements TextBlockBackcol
 
 		final double round = styleNode.value(PName.RoundCorner).asDouble();
 		final URectangle fullNodeRectangle = new URectangle(trueWidth, y).rounded(round);
-		final HColor backColor = styleNode.value(PName.BackGroundColor).asColor(skinParam.getThemeStyle(),
-				skinParam.getIHtmlColorSet());
+		final HColor backColor = styleNode.value(PName.BackGroundColor).asColor(skinParam.getIHtmlColorSet());
 		ugNode.apply(backColor.bg()).apply(backColor).draw(fullNodeRectangle);
 
 		final Style styleSeparator = styleNode.getSignature().add(SName.separator)
 				.getMergedStyle(skinParam.getCurrentStyleBuilder());
-		final UGraphic ugSeparator = styleSeparator.applyStrokeAndLineColor(ug, skinParam.getIHtmlColorSet(),
-				skinParam.getThemeStyle());
+		final UGraphic ugSeparator = styleSeparator.applyStrokeAndLineColor(ug, skinParam.getIHtmlColorSet());
 
 		y = 0;
 		for (Line line : lines) {
@@ -321,8 +316,7 @@ public class TextBlockJson extends AbstractTextBlock implements TextBlockBackcol
 
 	private TextBlock getTextBlock(Style style, String key) {
 		final Display display = Display.getWithNewlines(key);
-		final FontConfiguration fontConfiguration = style.getFontConfiguration(skinParam.getThemeStyle(),
-				skinParam.getIHtmlColorSet());
+		final FontConfiguration fontConfiguration = style.getFontConfiguration(skinParam.getIHtmlColorSet());
 		final LineBreakStrategy wrap = style.wrapWidth();
 		final HorizontalAlignment horizontalAlignment = style.getHorizontalAlignment();
 		TextBlock result = display.create0(fontConfiguration, horizontalAlignment, skinParam, wrap,
