@@ -35,7 +35,6 @@
  */
 package net.sourceforge.plantuml.math;
 
-import net.sourceforge.plantuml.api.ThemeStyle;
 import net.sourceforge.plantuml.command.PSystemBasicFactory;
 import net.sourceforge.plantuml.core.DiagramType;
 import net.sourceforge.plantuml.core.UmlSource;
@@ -47,7 +46,7 @@ public class PSystemMathFactory extends PSystemBasicFactory<PSystemMath> {
 	}
 
 	@Override
-	public PSystemMath initDiagram(ThemeStyle style, UmlSource source, String startLine) {
+	public PSystemMath initDiagram(UmlSource source, String startLine) {
 		if (getDiagramType() == DiagramType.MATH)
 			return new PSystemMath(source);
 
@@ -55,7 +54,7 @@ public class PSystemMathFactory extends PSystemBasicFactory<PSystemMath> {
 	}
 
 	@Override
-	public PSystemMath executeLine(ThemeStyle style, UmlSource source, PSystemMath system, String line) {
+	public PSystemMath executeLine(UmlSource source, PSystemMath system, String line) {
 		system.doCommandLine(line);
 		return system;
 	}
