@@ -52,6 +52,7 @@ import net.sourceforge.plantuml.api.ImageDataSimple;
 import net.sourceforge.plantuml.core.ImageData;
 import net.sourceforge.plantuml.eps.EpsGraphics;
 import net.sourceforge.plantuml.graphic.GraphicStrings;
+import net.sourceforge.plantuml.log.Logme;
 import net.sourceforge.plantuml.security.SImageIO;
 import net.sourceforge.plantuml.svek.TextBlockBackcolored;
 import net.sourceforge.plantuml.ugraphic.AffineTransformType;
@@ -73,7 +74,7 @@ public class ScientificEquationSafe {
 		try {
 			return new ScientificEquationSafe(formula, new AsciiMath(formula));
 		} catch (Exception e) {
-			e.printStackTrace();
+			Logme.error(e);
 			Log.info("Error parsing " + formula);
 			return new ScientificEquationSafe(formula, null);
 		}
@@ -83,7 +84,7 @@ public class ScientificEquationSafe {
 		try {
 			return new ScientificEquationSafe(formula, new LatexBuilder(formula));
 		} catch (Exception e) {
-			e.printStackTrace();
+			Logme.error(e);
 			Log.info("Error parsing " + formula);
 			return new ScientificEquationSafe(formula, null);
 		}
@@ -129,7 +130,7 @@ public class ScientificEquationSafe {
 		if (equation != null) {
 			System.err.println("Latex=" + equation.getSource());
 		}
-		e.printStackTrace();
+		Logme.error(e);
 	}
 
 	private TextBlockBackcolored getRollback() {
