@@ -35,20 +35,18 @@
  */
 package net.sourceforge.plantuml.mindmap;
 
-import java.awt.geom.Rectangle2D;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.util.ArrayList;
 import java.util.List;
 
-import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.Direction;
 import net.sourceforge.plantuml.FileFormatOption;
 import net.sourceforge.plantuml.SkinParam;
 import net.sourceforge.plantuml.UmlDiagram;
 import net.sourceforge.plantuml.UmlDiagramType;
-import net.sourceforge.plantuml.api.ThemeStyle;
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
+import net.sourceforge.plantuml.awt.geom.XRectangle2D;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
 import net.sourceforge.plantuml.core.DiagramDescription;
 import net.sourceforge.plantuml.core.ImageData;
@@ -77,8 +75,8 @@ public class MindMapDiagram extends UmlDiagram {
 		return new DiagramDescription("MindMap");
 	}
 
-	public MindMapDiagram(ThemeStyle style, UmlSource source) {
-		super(style, source, UmlDiagramType.MINDMAP, null);
+	public MindMapDiagram(UmlSource source) {
+		super(source, UmlDiagramType.MINDMAP, null);
 		((SkinParam) getSkinParam()).setRankdir(Rankdir.LEFT_TO_RIGHT);
 		this.mindmaps.add(new MindMap(getSkinParam()));
 	}
@@ -96,24 +94,24 @@ public class MindMapDiagram extends UmlDiagram {
 			public void drawU(UGraphic ug) {
 				for (MindMap mindmap : mindmaps) {
 					mindmap.drawU(ug);
-					final Dimension2D dim = mindmap.calculateDimension(ug.getStringBounder());
+					final XDimension2D dim = mindmap.calculateDimension(ug.getStringBounder());
 					ug = ug.apply(UTranslate.dy(dim.getHeight()));
 				}
 			}
 
-			public Rectangle2D getInnerPosition(String member, StringBounder stringBounder, InnerStrategy strategy) {
+			public XRectangle2D getInnerPosition(String member, StringBounder stringBounder, InnerStrategy strategy) {
 				return null;
 			}
 
-			public Dimension2D calculateDimension(StringBounder stringBounder) {
+			public XDimension2D calculateDimension(StringBounder stringBounder) {
 				double width = 0;
 				double height = 0;
 				for (MindMap mindmap : mindmaps) {
-					final Dimension2D dim = mindmap.calculateDimension(stringBounder);
+					final XDimension2D dim = mindmap.calculateDimension(stringBounder);
 					height += dim.getHeight();
 					width = Math.max(width, dim.getWidth());
 				}
-				return new Dimension2DDouble(width, height);
+				return new XDimension2D(width, height);
 			}
 
 			public MinMax getMinMax(StringBounder stringBounder) {
