@@ -51,9 +51,9 @@ public class ReadLineReader implements ReadLine {
 	private final String description;
 
 	private ReadLineReader(Reader reader, String description, LineLocation parent) {
-		if (description == null) {
+		if (description == null)
 			description = "?";
-		}
+
 		this.br = new BufferedReader(reader);
 		this.location = new LineLocationImpl(description, parent);
 		this.description = description;
@@ -80,16 +80,16 @@ public class ReadLineReader implements ReadLine {
 	public StringLocated readLine() throws IOException {
 		String s = br.readLine();
 		location = location.oneLineRead();
-		if (s == null) {
+		if (s == null)
 			return null;
-		}
+
 		// if (s.length() > LIMIT) {
 		// Log.debug("Line truncated from " + s.length() + " to " + LIMIT);
 		// s = s.substring(0, LIMIT);
 		// }
-		if (s.startsWith("\uFEFF")) {
+		if (s.startsWith("\uFEFF"))
 			s = s.substring(1);
-		}
+
 		s = s.replace('\u2013', '-');
 		// s = BackSlash.convertHiddenNewLine(s);
 		// s = s.replace('\u00A0', ' ');
