@@ -55,7 +55,7 @@ public class ComplementWithColorLink implements Something {
 		final String color1 = arg.get("COMPLEMENT" + suffix, 1);
 		final String style2 = arg.get("COMPLEMENT" + suffix, 2);
 		final HColor col1 = color1 == null ? null
-				: diagram.getIHtmlColorSet().getColorOrWhite(diagram.getSkinParam().getThemeStyle(), color1);
+				: diagram.getIHtmlColorSet().getColorOrWhite(color1);
 		final String style = style0 == null ? style2 : style0;
 		return Failable.ok(new CenterBorderColor(col1, col1, style));
 	}
