@@ -35,15 +35,14 @@
  */
 package net.sourceforge.plantuml.salt.element;
 
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Iterator;
 import java.util.List;
 
-import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.ISkinSimple;
 import net.sourceforge.plantuml.StringUtils;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.ugraphic.UFont;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
@@ -80,11 +79,11 @@ public class ElementTree extends AbstractElement {
 		}
 	}
 
-	public Dimension2D getPreferredDimension(StringBounder stringBounder, double x, double y) {
+	public XDimension2D getPreferredDimension(StringBounder stringBounder, double x, double y) {
 		double w1 = 0;
 		double h = 0;
 		for (ElementTreeEntry entry : entries) {
-			final Dimension2D dim1 = entry.getPreferredDimensionFirstCell(stringBounder);
+			final XDimension2D dim1 = entry.getPreferredDimensionFirstCell(stringBounder);
 			w1 = Math.max(w1, dim1.getWidth());
 			h += dim1.getHeight();
 		}
@@ -92,7 +91,7 @@ public class ElementTree extends AbstractElement {
 		if (w2 > 0) {
 			w2 += margin;
 		}
-		return new Dimension2DDouble(w1 + w2 + 2, h);
+		return new XDimension2D(w1 + w2 + 2, h);
 	}
 
 	private ListWidth getWidthOther(StringBounder stringBounder) {
@@ -107,13 +106,13 @@ public class ElementTree extends AbstractElement {
 	private double getWidth1(StringBounder stringBounder) {
 		double w1 = 0;
 		for (ElementTreeEntry entry : entries) {
-			final Dimension2D dim1 = entry.getPreferredDimensionFirstCell(stringBounder);
+			final XDimension2D dim1 = entry.getPreferredDimensionFirstCell(stringBounder);
 			w1 = Math.max(w1, dim1.getWidth());
 		}
 		return w1;
 	}
 
-	public void drawU(UGraphic ug, int zIndex, Dimension2D dimToUse) {
+	public void drawU(UGraphic ug, int zIndex, XDimension2D dimToUse) {
 		if (zIndex != 0)
 			return;
 
