@@ -35,9 +35,8 @@
  */
 package net.sourceforge.plantuml.sdot;
 
-import java.awt.geom.CubicCurve2D;
-import java.awt.geom.Point2D;
-
+import net.sourceforge.plantuml.awt.geom.XCubicCurve2D;
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
 import net.sourceforge.plantuml.posimo.DotPath;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
 
@@ -56,14 +55,14 @@ public class YMirror {
 		return max - v;
 	}
 
-	public Point2D getMirrored(Point2D pt) {
+	public XPoint2D getMirrored(XPoint2D pt) {
 		// return pt;
-		return new Point2D.Double(pt.getX(), max - pt.getY());
+		return new XPoint2D(pt.getX(), max - pt.getY());
 	}
 
 	public DotPath getMirrored(DotPath path) {
 		DotPath result = new DotPath();
-		for (CubicCurve2D.Double bez : path.getBeziers()) {
+		for (XCubicCurve2D bez : path.getBeziers()) {
 			result = result.addCurve(getMirrored(bez.getP1()), getMirrored(bez.getCtrlP1()),
 					getMirrored(bez.getCtrlP2()), getMirrored(bez.getP2()));
 		}
