@@ -91,7 +91,7 @@ public class CommandReferenceMultilinesOverSeveral extends CommandMultilines<Seq
 
 		final String s1 = arg.get("REF", 0);
 		final HColor backColorElement = s1 == null ? null
-				: diagram.getSkinParam().getIHtmlColorSet().getColor(diagram.getSkinParam().getThemeStyle(), s1);
+				: diagram.getSkinParam().getIHtmlColorSet().getColor(s1);
 		// final HtmlColor backColorGeneral =
 		// HtmlColorSetSimple.instance().getColorIfValid(line0.get(1));
 
