@@ -35,7 +35,6 @@
  */
 package net.sourceforge.plantuml.skin;
 
-import net.sourceforge.plantuml.UseStyle;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.StyleSignatureBasic;
 import net.sourceforge.plantuml.style.Styleable;
@@ -46,7 +45,8 @@ public enum ComponentType implements Styleable {
 
 	ACTOR_HEAD, ACTOR_TAIL,
 
-	BOUNDARY_HEAD, BOUNDARY_TAIL, CONTROL_HEAD, CONTROL_TAIL, ENTITY_HEAD, ENTITY_TAIL, QUEUE_HEAD, QUEUE_TAIL, DATABASE_HEAD, DATABASE_TAIL, COLLECTIONS_HEAD, COLLECTIONS_TAIL,
+	BOUNDARY_HEAD, BOUNDARY_TAIL, CONTROL_HEAD, CONTROL_TAIL, ENTITY_HEAD, ENTITY_TAIL, QUEUE_HEAD, QUEUE_TAIL,
+	DATABASE_HEAD, DATABASE_TAIL, COLLECTIONS_HEAD, COLLECTIONS_TAIL,
 
 	//
 	ALIVE_BOX_CLOSE_CLOSE, ALIVE_BOX_CLOSE_OPEN, ALIVE_BOX_OPEN_CLOSE, ALIVE_BOX_OPEN_OPEN,
@@ -71,51 +71,38 @@ public enum ComponentType implements Styleable {
 	}
 
 	public StyleSignatureBasic getStyleSignature() {
-		if (this == PARTICIPANT_HEAD || this == PARTICIPANT_TAIL) {
-			return StyleSignatureBasic.of(SName.root, SName.element,
-					SName.sequenceDiagram, SName.participant);
-		}
-		if (this == PARTICIPANT_LINE || this == CONTINUE_LINE) {
-			return StyleSignatureBasic.of(SName.root, SName.element,
-					SName.sequenceDiagram, SName.lifeLine);
-		}
+		if (this == PARTICIPANT_HEAD || this == PARTICIPANT_TAIL)
+			return StyleSignatureBasic.of(SName.root, SName.element, SName.sequenceDiagram, SName.participant);
+
+		if (this == PARTICIPANT_LINE || this == CONTINUE_LINE)
+			return StyleSignatureBasic.of(SName.root, SName.element, SName.sequenceDiagram, SName.lifeLine);
+
 		if (this == ALIVE_BOX_CLOSE_CLOSE || this == ALIVE_BOX_CLOSE_OPEN || this == ALIVE_BOX_OPEN_CLOSE
-				|| this == ALIVE_BOX_OPEN_OPEN) {
-			return StyleSignatureBasic.of(SName.root, SName.element,
-					SName.sequenceDiagram, SName.lifeLine);
-		}
-		if (this == DESTROY) {
-			return StyleSignatureBasic.of(SName.root, SName.element,
-					SName.sequenceDiagram, SName.lifeLine);
-		}
-		if (this == DIVIDER) {
-			return StyleSignatureBasic.of(SName.root, SName.element,
-					SName.sequenceDiagram, SName.separator);
-		}
-		if (this == ENGLOBER) {
-			return StyleSignatureBasic.of(SName.root, SName.element,
-					SName.sequenceDiagram, SName.box);
-		}
-		if (this == NOTE) {
-			return StyleSignatureBasic.of(SName.root, SName.element,
-					SName.sequenceDiagram, SName.note);
-		}
-		if (this == DELAY_TEXT) {
-			return StyleSignatureBasic.of(SName.root, SName.element,
-					SName.sequenceDiagram, SName.delay);
-		}
-		if (this == DELAY_LINE) {
-			return StyleSignatureBasic.of(SName.root, SName.element,
-					SName.sequenceDiagram, SName.delay);
-		}
+				|| this == ALIVE_BOX_OPEN_OPEN)
+			return StyleSignatureBasic.of(SName.root, SName.element, SName.sequenceDiagram, SName.lifeLine);
+
+		if (this == DESTROY)
+			return StyleSignatureBasic.of(SName.root, SName.element, SName.sequenceDiagram, SName.lifeLine);
+
+		if (this == DIVIDER)
+			return StyleSignatureBasic.of(SName.root, SName.element, SName.sequenceDiagram, SName.separator);
+
+		if (this == ENGLOBER)
+			return StyleSignatureBasic.of(SName.root, SName.element, SName.sequenceDiagram, SName.box);
+
+		if (this == NOTE)
+			return StyleSignatureBasic.of(SName.root, SName.element, SName.sequenceDiagram, SName.note);
+
+		if (this == DELAY_TEXT)
+			return StyleSignatureBasic.of(SName.root, SName.element, SName.sequenceDiagram, SName.delay);
+
+		if (this == DELAY_LINE)
+			return StyleSignatureBasic.of(SName.root, SName.element, SName.sequenceDiagram, SName.delay);
+
 //		if (this == REFERENCE) {
 //			return StyleSignature.of(SName.root, SName.element,
 //					SName.sequenceDiagram, SName.reference);
 //		}
-		if (UseStyle.useBetaStyle()) {
-			throw new UnsupportedOperationException(toString());
-
-		}
-		return StyleSignatureBasic.of(SName.root);
+		throw new UnsupportedOperationException(toString());
 	}
 }
