@@ -36,11 +36,10 @@
 package net.sourceforge.plantuml.sprite;
 
 import net.sourceforge.plantuml.graphic.TextBlock;
-import net.sourceforge.plantuml.ugraphic.color.ColorMapper;
 import net.sourceforge.plantuml.ugraphic.color.HColor;
 
 public interface Sprite {
 
-	public TextBlock asTextBlock(final HColor color, double scale, ColorMapper colorMapper);
+	public TextBlock asTextBlock(final HColor color, double scale);
 
 }
