@@ -38,8 +38,7 @@ package net.sourceforge.plantuml.sprite;
 import java.awt.Color;
 import java.awt.image.BufferedImage;
 
-import net.sourceforge.plantuml.Dimension2DDouble;
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
 import net.sourceforge.plantuml.graphic.AbstractTextBlock;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.TextBlock;
@@ -124,7 +123,7 @@ public class SpriteColor implements Sprite {
 		return new UImage(new PixelImage(im, AffineTransformType.TYPE_BILINEAR));
 	}
 
-	public TextBlock asTextBlock(final HColor color, final double scale, ColorMapper colorMapper) {
+	public TextBlock asTextBlock(final HColor color, final double scale) {
 		return new AbstractTextBlock() {
 
 			public void drawU(UGraphic ug) {
@@ -132,8 +131,8 @@ public class SpriteColor implements Sprite {
 				ug.draw(image.scale(scale));
 			}
 
-			public Dimension2D calculateDimension(StringBounder stringBounder) {
-				return new Dimension2DDouble(getWidth() * scale, getHeight() * scale);
+			public XDimension2D calculateDimension(StringBounder stringBounder) {
+				return new XDimension2D(getWidth() * scale, getHeight() * scale);
 			}
 		};
 	}
