@@ -37,7 +37,6 @@
  */
 package net.sourceforge.plantuml.svek;
 
-import java.awt.geom.Rectangle2D;
 import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
@@ -48,8 +47,6 @@ import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
 import net.sourceforge.plantuml.BaseFile;
-import net.sourceforge.plantuml.Dimension2DDouble;
-import net.sourceforge.plantuml.FontParam;
 import net.sourceforge.plantuml.Guillemet;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.LineParam;
@@ -59,12 +56,9 @@ import net.sourceforge.plantuml.Pragma;
 import net.sourceforge.plantuml.SkinParamSameClassWidth;
 import net.sourceforge.plantuml.StringUtils;
 import net.sourceforge.plantuml.UmlDiagramType;
-import net.sourceforge.plantuml.activitydiagram3.ftile.EntityImageLegend;
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
+import net.sourceforge.plantuml.awt.geom.XRectangle2D;
 import net.sourceforge.plantuml.core.UmlSource;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.cucadiagram.DisplayPositioned;
-import net.sourceforge.plantuml.cucadiagram.EntityPortion;
 import net.sourceforge.plantuml.cucadiagram.EntityPosition;
 import net.sourceforge.plantuml.cucadiagram.GroupRoot;
 import net.sourceforge.plantuml.cucadiagram.GroupType;
@@ -82,23 +76,20 @@ import net.sourceforge.plantuml.cucadiagram.dot.GraphvizUtils;
 import net.sourceforge.plantuml.cucadiagram.dot.GraphvizVersion;
 import net.sourceforge.plantuml.cucadiagram.dot.Neighborhood;
 import net.sourceforge.plantuml.cucadiagram.entity.EntityFactory;
+import net.sourceforge.plantuml.cucadiagram.entity.EntityImpl;
 import net.sourceforge.plantuml.descdiagram.EntityImageDesignedDomain;
 import net.sourceforge.plantuml.descdiagram.EntityImageDomain;
 import net.sourceforge.plantuml.descdiagram.EntityImageMachine;
 import net.sourceforge.plantuml.descdiagram.EntityImageRequirement;
 import net.sourceforge.plantuml.graphic.FontConfiguration;
 import net.sourceforge.plantuml.graphic.GraphicStrings;
-import net.sourceforge.plantuml.graphic.HorizontalAlignment;
 import net.sourceforge.plantuml.graphic.InnerStrategy;
 import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.TextBlock;
-import net.sourceforge.plantuml.graphic.TextBlockEmpty;
-import net.sourceforge.plantuml.graphic.TextBlockUtils;
-import net.sourceforge.plantuml.graphic.USymbol;
 import net.sourceforge.plantuml.graphic.USymbolHexagon;
 import net.sourceforge.plantuml.graphic.USymbolInterface;
-import net.sourceforge.plantuml.graphic.USymbols;
 import net.sourceforge.plantuml.log.Logme;
+import net.sourceforge.plantuml.security.SecurityProfile;
+import net.sourceforge.plantuml.security.SecurityUtils;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
@@ -155,8 +146,7 @@ public final class GeneralImageBuilder {
 			throw new IllegalStateException();
 
 		if (leaf.getLeafType().isLikeClass()) {
-			final EntityImageClass entityImageClass = new EntityImageClass(graphvizVersion, (ILeaf) leaf, skinParam,
-					portionShower);
+			final EntityImageClass entityImageClass = new EntityImageClass((ILeaf) leaf, skinParam, portionShower);
 			final Neighborhood neighborhood = leaf.getNeighborhood();
 			if (neighborhood != null)
 				return new EntityImageProtected(entityImageClass, 20, neighborhood, bibliotekon);
@@ -169,8 +159,8 @@ public final class GeneralImageBuilder {
 		if (leaf.getLeafType() == LeafType.ACTIVITY)
 			return new EntityImageActivity(leaf, skinParam, bibliotekon);
 
-		if ((leaf.getLeafType() == LeafType.PORT) || (leaf.getLeafType() == LeafType.PORTIN)
-				|| (leaf.getLeafType() == LeafType.PORTOUT)) {
+		if (/* (leaf.getLeafType() == LeafType.PORT) || */leaf.getLeafType() == LeafType.PORTIN
+				|| leaf.getLeafType() == LeafType.PORTOUT) {
 			final Cluster parent = bibliotekon.getCluster(leaf.getParentContainer());
 			return new EntityImagePort(leaf, skinParam, parent, bibliotekon, umlDiagramType.getStyleName());
 		}
@@ -352,15 +342,15 @@ public final class GeneralImageBuilder {
 			return backColor;
 		}
 
-		public Dimension2D calculateDimension(StringBounder stringBounder) {
-			return new Dimension2DDouble(10, 10);
+		public XDimension2D calculateDimension(StringBounder stringBounder) {
+			return new XDimension2D(10, 10);
 		}
 
 		public MinMax getMinMax(StringBounder stringBounder) {
 			return MinMax.fromDim(calculateDimension(stringBounder));
 		}
 
-		public Rectangle2D getInnerPosition(String member, StringBounder stringBounder, InnerStrategy strategy) {
+		public XRectangle2D getInnerPosition(String member, StringBounder stringBounder, InnerStrategy strategy) {
 			return null;
 		}
 
@@ -385,8 +375,7 @@ public final class GeneralImageBuilder {
 	private HColor getBackcolor() {
 		final Style style = StyleSignatureBasic.of(SName.root, SName.document)
 				.getMergedStyle(dotData.getSkinParam().getCurrentStyleBuilder());
-		return style.value(PName.BackGroundColor).asColor(dotData.getSkinParam().getThemeStyle(),
-				dotData.getSkinParam().getIHtmlColorSet());
+		return style.value(PName.BackGroundColor).asColor(dotData.getSkinParam().getIHtmlColorSet());
 	}
 
 	public IEntityImage buildImage(BaseFile basefile, String dotStrings[]) {
@@ -418,7 +407,7 @@ public final class GeneralImageBuilder {
 				final FontConfiguration labelFont = getFontForLink(link, skinParam);
 
 				final SvekLine line = new SvekLine(link, dotStringFactory.getColorSequence(), skinParam, stringBounder,
-						labelFont, dotStringFactory.getBibliotekon(), pragma);
+						labelFont, dotStringFactory.getBibliotekon(), pragma, dotStringFactory.getGraphvizVersion());
 
 				dotStringFactory.getBibliotekon().addLine(line);
 
@@ -445,7 +434,10 @@ public final class GeneralImageBuilder {
 		if (dotStringFactory.illegalDotExe())
 			return error(dotStringFactory.getDotExe());
 
-		if (basefile == null && isSvekTrace())
+		if (basefile == null && isSvekTrace()
+				&& (SecurityUtils.getSecurityProfile() == SecurityProfile.UNSECURE
+						|| SecurityUtils.getSecurityProfile() == SecurityProfile.LEGACY
+						|| SecurityUtils.getSecurityProfile() == SecurityProfile.SANDBOX))
 			basefile = new BaseFile(null);
 
 		final String svg;
@@ -473,7 +465,7 @@ public final class GeneralImageBuilder {
 
 	private FontConfiguration getFontForLink(Link link, final ISkinParam skinParam) {
 		final Style style = getDefaultStyleDefinitionArrow(link.getStereotype()).getMergedStyle(link.getStyleBuilder());
-		return style.getFontConfiguration(skinParam.getThemeStyle(), skinParam.getIHtmlColorSet());
+		return style.getFontConfiguration(skinParam.getIHtmlColorSet());
 	}
 
 	private boolean isSvekTrace() {
@@ -551,7 +543,7 @@ public final class GeneralImageBuilder {
 		if (ent.getSvekImage() == null) {
 			ISkinParam skinParam = dotData.getSkinParam();
 			if (skinParam.sameClassWidth()) {
-				final double width = getMaxWidth(dotStringFactory);
+				final double width = getMaxWidth();
 				skinParam = new SkinParamSameClassWidth(skinParam, width);
 			}
 
@@ -562,14 +554,13 @@ public final class GeneralImageBuilder {
 		return ent.getSvekImage();
 	}
 
-	private double getMaxWidth(DotStringFactory dotStringFactory) {
+	private double getMaxWidth() {
 		double result = 0;
 		for (ILeaf ent : dotData.getLeafs()) {
 			if (ent.getLeafType().isLikeClass() == false)
 				continue;
 
-			final IEntityImage im = new EntityImageClass(dotStringFactory.getGraphvizVersion(), ent,
-					dotData.getSkinParam(), dotData);
+			final IEntityImage im = new EntityImageClass(ent, dotData.getSkinParam(), dotData);
 			final double w = im.calculateDimension(stringBounder).getWidth();
 			if (w > result)
 				result = w;
@@ -615,29 +606,10 @@ public final class GeneralImageBuilder {
 				return;
 			}
 		}
-		int titleAndAttributeWidth = 0;
-		int titleAndAttributeHeight = 0;
 
-		final TextBlock title = getTitleBlock(g);
-		final TextBlock stereo = getStereoBlock(g);
-		final TextBlock stereoAndTitle = TextBlockUtils.mergeTB(stereo, title, HorizontalAlignment.CENTER);
-		final Dimension2D dimLabel = stereoAndTitle.calculateDimension(stringBounder);
-		if (dimLabel.getWidth() > 0) {
-			final Dimension2D dimAttribute = stateHeader((IEntity) g, getStyleState(FontParam.STATE_ATTRIBUTE),
-					dotData.getSkinParam()).calculateDimension(stringBounder);
-			final double attributeHeight = dimAttribute.getHeight();
-			final double attributeWidth = dimAttribute.getWidth();
-			final double marginForFields = attributeHeight > 0 ? IEntityImage.MARGIN : 0;
-			final USymbol uSymbol = g.getUSymbol();
-			final int suppHeightBecauseOfShape = uSymbol == null ? 0 : uSymbol.suppHeightBecauseOfShape();
-			final int suppWidthBecauseOfShape = uSymbol == null ? 0 : uSymbol.suppWidthBecauseOfShape();
-
-			titleAndAttributeWidth = (int) Math.max(dimLabel.getWidth(), attributeWidth) + suppWidthBecauseOfShape;
-			titleAndAttributeHeight = (int) (dimLabel.getHeight() + attributeHeight + marginForFields
-					+ suppHeightBecauseOfShape);
-		}
-
-		dotStringFactory.openCluster(titleAndAttributeWidth, titleAndAttributeHeight, title, stereo, g);
+		final ClusterHeader clusterHeader = new ClusterHeader((EntityImpl) g, dotData.getSkinParam(), dotData,
+				stringBounder);
+		dotStringFactory.openCluster(g, clusterHeader);
 		this.printEntities(dotStringFactory, g.getLeafsDirect());
 
 		printGroups(dotStringFactory, g);
@@ -645,106 +617,6 @@ public final class GeneralImageBuilder {
 		dotStringFactory.closeCluster();
 	}
 
-	public static TextBlock stateHeader(IEntity group, Style style, ISkinParam skinParam) {
-		final List<CharSequence> details = group.getBodier().getRawBody();
-
-		if (details.size() == 0)
-			return new TextBlockEmpty();
-
-		final FontConfiguration fontConfiguration;
-		if (style == null)
-			fontConfiguration = FontConfiguration.create(skinParam, FontParam.STATE_ATTRIBUTE, null);
-		else
-			fontConfiguration = FontConfiguration.create(skinParam, style);
-
-		Display display = null;
-		for (CharSequence s : details)
-			if (display == null)
-				display = Display.getWithNewlines(s.toString());
-			else
-				display = display.addAll(Display.getWithNewlines(s.toString()));
-
-		return display.create(fontConfiguration, HorizontalAlignment.LEFT, skinParam);
-
-	}
-
-	private Style getStyleState(FontParam fontParam) {
-		return fontParam.getStyleDefinition(SName.stateDiagram)
-				.getMergedStyle(dotData.getSkinParam().getCurrentStyleBuilder());
-	}
-
-	private TextBlock getTitleBlock(IGroup g) {
-		final Display label = g.getDisplay();
-		if (label == null)
-			return TextBlockUtils.empty(0, 0);
-
-		final ISkinParam skinParam = dotData.getSkinParam();
-
-		final SName sname = dotData.getUmlDiagramType().getStyleName();
-		final StyleSignatureBasic signature;
-		final USymbol uSymbol = g.getUSymbol();
-		if (g.getGroupType() == GroupType.STATE)
-			signature = StyleSignatureBasic.of(SName.root, SName.element, SName.stateDiagram, SName.state,
-					SName.header);
-		else if (uSymbol == USymbols.RECTANGLE)
-			signature = StyleSignatureBasic.of(SName.root, SName.element, sname, uSymbol.getSName(), SName.title);
-		else
-			signature = StyleSignatureBasic.of(SName.root, SName.element, sname, SName.title);
-
-		final Style style = signature //
-				.withTOBECHANGED(g.getStereotype()) //
-				.with(g.getStereostyles()) //
-				.getMergedStyle(skinParam.getCurrentStyleBuilder());
-
-		final FontConfiguration fontConfiguration = style.getFontConfiguration(skinParam.getThemeStyle(),
-				skinParam.getIHtmlColorSet());
-
-		final HorizontalAlignment alignment = HorizontalAlignment.CENTER;
-		return label.create(fontConfiguration, alignment, dotData.getSkinParam());
-	}
-
-	private TextBlock addLegend(TextBlock original, DisplayPositioned legend) {
-		if (legend == null || legend.isNull())
-			return original;
-
-		final TextBlock legendBlock = EntityImageLegend.create(legend.getDisplay(), dotData.getSkinParam());
-		return DecorateEntityImage.add(legendBlock, original, legend.getHorizontalAlignment(),
-				legend.getVerticalAlignment());
-	}
-
-	private TextBlock getStereoBlock(IGroup g) {
-		final DisplayPositioned legend = g.getLegend();
-		return addLegend(getStereoBlockWithoutLegend(g), legend);
-	}
-
-	private TextBlock getStereoBlockWithoutLegend(IGroup g) {
-		final Stereotype stereotype = g.getStereotype();
-		// final DisplayPositionned legend = g.getLegend();
-		if (stereotype == null)
-			return TextBlockUtils.empty(0, 0);
-
-		final TextBlock tmp = stereotype.getSprite(dotData.getSkinParam());
-		if (tmp != null)
-			return tmp;
-
-		final List<String> stereos = stereotype.getLabels(dotData.getSkinParam().guillemet());
-		if (stereos == null)
-			return TextBlockUtils.empty(0, 0);
-
-		final boolean show = dotData.showPortion(EntityPortion.STEREOTYPE, g);
-		if (show == false)
-			return TextBlockUtils.empty(0, 0);
-
-		final Style style = Cluster
-				.getDefaultStyleDefinition(dotData.getUmlDiagramType().getStyleName(), g.getUSymbol())
-				.forStereotypeItself(g.getStereotype()).getMergedStyle(dotData.getSkinParam().getCurrentStyleBuilder());
-
-		final FontConfiguration fontConfiguration = style.getFontConfiguration(dotData.getSkinParam().getThemeStyle(),
-				dotData.getSkinParam().getIHtmlColorSet());
-		return Display.create(stereos).create(fontConfiguration, HorizontalAlignment.CENTER, dotData.getSkinParam());
-
-	}
-
 	public String getWarningOrError(int warningOrError) {
 		if (maxX == null)
 			return "";
