@@ -37,7 +37,17 @@ package net.sourceforge.plantuml.svek;
 
 public enum ShapeType {
 
-	RECTANGLE, RECTANGLE_WITH_CIRCLE_INSIDE, RECTANGLE_HTML_FOR_PORTS, ROUND_RECTANGLE, CIRCLE, CIRCLE_IN_RECT, OVAL,
-	DIAMOND, OCTAGON, FOLDER, HEXAGON
+	RECTANGLE, //
+	RECTANGLE_PORT, //
+	RECTANGLE_WITH_CIRCLE_INSIDE, //
+	RECTANGLE_HTML_FOR_PORTS, //
+	ROUND_RECTANGLE, //
+	CIRCLE, //
+	OVAL, //
+	DIAMOND, //
+	OCTAGON, //
+	FOLDER, //
+	HEXAGON, //
+	PORT //
 
 }
