@@ -36,8 +36,8 @@
 package net.sourceforge.plantuml.svek.extremity;
 
 import java.awt.geom.AffineTransform;
-import java.awt.geom.Point2D;
 
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
 import net.sourceforge.plantuml.svek.Side;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.ULine;
@@ -45,17 +45,17 @@ import net.sourceforge.plantuml.ugraphic.UTranslate;
 
 class ExtremityCrowfoot extends Extremity {
 
-	private final Point2D contact;
+	private final XPoint2D contact;
 	private double angle;
 	private final Side side;
 
 	@Override
-	public Point2D somePoint() {
+	public XPoint2D somePoint() {
 		return contact;
 	}
 
-	public ExtremityCrowfoot(Point2D p1, double angle, Side side) {
-		this.contact = new Point2D.Double(p1.getX(), p1.getY());
+	public ExtremityCrowfoot(XPoint2D p1, double angle, Side side) {
+		this.contact = new XPoint2D(p1.getX(), p1.getY());
 		this.angle = manageround(angle + Math.PI / 2);
 		this.side = side;
 	}
@@ -64,21 +64,21 @@ class ExtremityCrowfoot extends Extremity {
 		final int xWing = 8;
 		final int yAperture = 8;
 		final AffineTransform rotate = AffineTransform.getRotateInstance(this.angle);
-		Point2D middle = new Point2D.Double(0, 0);
-		Point2D left = new Point2D.Double(0, -yAperture);
-		Point2D base = new Point2D.Double(-xWing, 0);
-		Point2D right = new Point2D.Double(0, yAperture);
-		rotate.transform(left, left);
-		rotate.transform(base, base);
-		rotate.transform(right, right);
+		XPoint2D middle = new XPoint2D(0, 0);
+		XPoint2D left = new XPoint2D(0, -yAperture);
+		XPoint2D base = new XPoint2D(-xWing, 0);
+		XPoint2D right = new XPoint2D(0, yAperture);
+		left = left.transform(rotate);
+		base = base.transform(rotate);
+		right = right.transform(rotate);
 
 		if (side == Side.WEST || side == Side.EAST) {
-			left.setLocation(middle.getX(), left.getY());
-			right.setLocation(middle.getX(), right.getY());
+			left = new XPoint2D(middle.getX(), left.getY());
+			right = new XPoint2D(middle.getX(), right.getY());
 		}
 		if (side == Side.SOUTH || side == Side.NORTH) {
-			left.setLocation(left.getX(), middle.getY());
-			right.setLocation(right.getX(), middle.getY());
+			left = new XPoint2D(left.getX(), middle.getY());
+			right = new XPoint2D(right.getX(), middle.getY());
 		}
 
 		drawLine(ug, contact.getX(), contact.getY(), base, left);
@@ -86,7 +86,7 @@ class ExtremityCrowfoot extends Extremity {
 		drawLine(ug, contact.getX(), contact.getY(), base, middle);
 	}
 
-	static private void drawLine(UGraphic ug, double x, double y, Point2D p1, Point2D p2) {
+	static private void drawLine(UGraphic ug, double x, double y, XPoint2D p1, XPoint2D p2) {
 		final double dx = p2.getX() - p1.getX();
 		final double dy = p2.getY() - p1.getY();
 		ug.apply(new UTranslate(x + p1.getX(), y + p1.getY())).draw(new ULine(dx, dy));
