@@ -35,8 +35,7 @@
  */
 package net.sourceforge.plantuml.svek.extremity;
 
-import java.awt.geom.Point2D;
-
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UPolygon;
 import net.sourceforge.plantuml.ugraphic.color.HColor;
@@ -45,16 +44,16 @@ class ExtremityExtends extends Extremity {
 
 	private UPolygon polygon = new UPolygon();
 	private final HColor fill;
-	private final Point2D contact;
+	private final XPoint2D contact;
 
 	@Override
-	public Point2D somePoint() {
+	public XPoint2D somePoint() {
 		return contact;
 	}
 
-	public ExtremityExtends(Point2D p1, double angle, HColor backgroundColor) {
+	public ExtremityExtends(XPoint2D p1, double angle, HColor backgroundColor) {
 		this.fill = backgroundColor;
-		this.contact = new Point2D.Double(p1.getX(), p1.getY());
+		this.contact = new XPoint2D(p1.getX(), p1.getY());
 		angle = manageround(angle);
 		polygon.addPoint(0, 0);
 		final double xWing = 19;// 8 * 2.4;
