@@ -35,8 +35,7 @@
  */
 package net.sourceforge.plantuml.svek.extremity;
 
-import java.awt.geom.Point2D;
-
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
 import net.sourceforge.plantuml.graphic.UDrawable;
 import net.sourceforge.plantuml.svek.AbstractExtremityFactory;
 import net.sourceforge.plantuml.svek.Side;
@@ -51,11 +50,12 @@ public class ExtremityFactoryPlus extends AbstractExtremityFactory implements Ex
 	}
 
 	@Override
-	public UDrawable createUDrawable(Point2D center, double angle, Side side) {
+	public UDrawable createUDrawable(XPoint2D center, double angle, Side side) {
 		return ExtremityPlus.create(center, angle - Math.PI / 2, backgroundColor);
 	}
 
-	public UDrawable createUDrawable(Point2D p0, Point2D p1, Point2D p2, Side side) {
+	@Override
+	public UDrawable createUDrawable(XPoint2D p0, XPoint2D p1, XPoint2D p2, Side side) {
 		final double ortho = atan2(p0, p2);
 		return ExtremityPlus.create(p1, ortho, backgroundColor);
 	}
