@@ -68,7 +68,7 @@ import org.w3c.dom.Element;
 import net.sourceforge.plantuml.FileUtils;
 import net.sourceforge.plantuml.Log;
 import net.sourceforge.plantuml.SignatureUtils;
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
 import net.sourceforge.plantuml.code.Base64Coder;
 import net.sourceforge.plantuml.log.Logme;
 import net.sourceforge.plantuml.security.SImageIO;
@@ -112,10 +112,6 @@ public class SvgGraphics {
 	private String fill = "black";
 	private String stroke = "black";
 
-//	private Collection<String> classesForDarkness = new LinkedHashSet<>();
-//	private String strokeDark = "black";
-//	private String fillDark = "black";
-
 	private String strokeWidth;
 	private String strokeDasharray = null;
 	private final String backcolor;
@@ -143,9 +139,8 @@ public class SvgGraphics {
 		}
 	}
 
-	public SvgGraphics(String backcolor, boolean svgDimensionStyle, Dimension2D minDim, double scale, String hover,
-			long seed, String preserveAspectRatio, LengthAdjust lengthAdjust, DarkStrategy darkStrategy,
-			boolean interactive) {
+	public SvgGraphics(String backcolor, boolean svgDimensionStyle, XDimension2D minDim, double scale, String hover,
+			long seed, String preserveAspectRatio, LengthAdjust lengthAdjust, boolean interactive) {
 		try {
 			this.lengthAdjust = lengthAdjust;
 			this.svgDimensionStyle = svgDimensionStyle;
@@ -259,7 +254,7 @@ public class SvgGraphics {
 	private Element pendingBackground;
 
 	public void paintBackcolorGradient(ColorMapper mapper, HColorGradient gr) {
-		final String id = createSvgGradient(mapper.toRGB(gr.getColor1()), mapper.toRGB(gr.getColor2()), gr.getPolicy());
+		final String id = createSvgGradient(gr.getColor1().toRGB(mapper), gr.getColor2().toRGB(mapper), gr.getPolicy());
 		setFillColor("url(#" + id + ")");
 		setStrokeColor(null);
 		pendingBackground = createRectangleInternal(0, 0, 0, 0);
@@ -311,7 +306,6 @@ public class SvgGraphics {
 			elt.setAttribute("ry", format(yRadius));
 			fillMe(elt);
 			elt.setAttribute("style", getStyle());
-			manageDarkStroke(elt);
 			addFilterShadowId(elt, deltaShadow);
 			getG().appendChild(elt);
 		}
@@ -379,23 +373,15 @@ public class SvgGraphics {
 	}
 
 	public final void setFillColor(String fill) {
-		this.fill = fill == null ? "none" : fill;
-		// this.fillDark = this.fill;
-	}
-
-	public final void setFillColor(String fill, String fillDark) {
-		this.fill = fill == null ? "none" : fill;
-		// this.fillDark = fillDark == null ? "none" : fillDark;
+		this.fill = fixColor(fill);
 	}
 
 	public final void setStrokeColor(String stroke) {
-		this.stroke = stroke == null ? "none" : stroke;
-		// this.strokeDark = stroke;
+		this.stroke = fixColor(stroke);
 	}
 
-	public final void setStrokeColor(String stroke, String strokeDark) {
-		this.stroke = stroke == null ? "none" : stroke;
-		// this.strokeDark = strokeDark == null ? "none" : strokeDark;
+	private String fixColor(String color) {
+		return color == null || "#00000000".equals(color) ? "none" : color;
 	}
 
 	public final void setStrokeWidth(double strokeWidth, String strokeDasharray) {
@@ -446,20 +432,9 @@ public class SvgGraphics {
 		elt.setAttribute("height", format(height));
 		fillMe(elt);
 		elt.setAttribute("style", getStyleSpecial());
-		manageDarkStroke(elt);
 		return elt;
 	}
 
-	private void manageDarkStroke(final Element elt) {
-//		if (strokeDark != null && stroke.equals(strokeDark) == false) {
-//			final String attribute = elt.getAttribute("class");
-//			if (attribute == null || attribute.length() == 0)
-//				elt.setAttribute("class", getStrokeClassForDark());
-//			else
-//				elt.setAttribute("class", attribute + " " + getStrokeClassForDark());
-//		}
-	}
-
 	public void svgLine(double x1, double y1, double x2, double y2, double deltaShadow) {
 		manageShadow(deltaShadow);
 		if (hidden == false) {
@@ -469,7 +444,6 @@ public class SvgGraphics {
 			elt.setAttribute("x2", format(x2));
 			elt.setAttribute("y2", format(y2));
 			elt.setAttribute("style", getStyle());
-			manageDarkStroke(elt);
 			addFilterShadowId(elt, deltaShadow);
 			getG().appendChild(elt);
 		}
@@ -479,7 +453,7 @@ public class SvgGraphics {
 
 	private String getStyle() {
 		final StringBuilder style = new StringBuilder();
-		// if (stroke.equals(strokeDark))
+
 		style.append("stroke:" + stroke + ";");
 		style.append("stroke-width:" + strokeWidth + ";");
 		if (fill.equals("#00000000"))
@@ -494,7 +468,7 @@ public class SvgGraphics {
 	// https://forum.plantuml.net/12469/package-background-transparent-package-default-background?show=12479#c12479
 	private String getStyleSpecial() {
 		final StringBuilder style = new StringBuilder();
-		// if (stroke.equals(strokeDark))
+
 		style.append("stroke:" + stroke + ";");
 		style.append("stroke-width:" + strokeWidth + ";");
 		if (fill.equals("#00000000"))
@@ -521,7 +495,6 @@ public class SvgGraphics {
 			elt.setAttribute("points", sb.toString());
 			fillMe(elt);
 			elt.setAttribute("style", getStyleSpecial());
-			manageDarkStroke(elt);
 			addFilterShadowId(elt, deltaShadow);
 			getG().appendChild(elt);
 		}
@@ -664,9 +637,6 @@ public class SvgGraphics {
 	}
 
 	private void createXmlInternal(OutputStream os) throws TransformerException {
-//		if (this.classesForDarkness.size() > 0)
-//			defs.appendChild(getStylesForDarkness());
-
 		// Get a DOMSource object that represents the
 		// Document object
 		final DOMSource source = new DOMSource(document);
@@ -674,7 +644,7 @@ public class SvgGraphics {
 		final int maxXscaled = (int) (maxX * scale);
 		final int maxYscaled = (int) (maxY * scale);
 		String style = "width:" + maxXscaled + "px;height:" + maxYscaled + "px;";
-		if (/* this.classesForDarkness.size() == 0 && */ backcolor != null)
+		if (backcolor != null)
 			style += "background:" + backcolor + ";";
 
 		if (svgDimensionStyle) {
@@ -742,7 +712,6 @@ public class SvgGraphics {
 			elt.setAttribute("d", sb.toString());
 			elt.setAttribute("style", getStyle());
 			fillMe(elt);
-			manageDarkStroke(elt);
 			final String id = path.getComment();
 			if (id != null)
 				elt.setAttribute("id", id);
@@ -756,32 +725,10 @@ public class SvgGraphics {
 		}
 	}
 
-//	private String getFillClassForDark() {
-//		final String result = "f_" + fill.toLowerCase().replaceAll("\\#", "") + "_"
-//				+ fillDark.toLowerCase().replaceAll("\\#", "");
-//		this.classesForDarkness.add(result);
-//		return result;
-//	}
-//
-//	private String getStrokeClassForDark() {
-//		final String result = "s_" + stroke.toLowerCase().replaceAll("\\#", "") + "_"
-//				+ strokeDark.toLowerCase().replaceAll("\\#", "");
-//		this.classesForDarkness.add(result);
-//		return result;
-//	}
-
 	private void fillMe(Element elt) {
 		if (fill.equals("#00000000"))
 			return;
 
-//		if (fill.equals(fillDark) == false) {
-//			if (elt.getAttribute("class") != null && elt.getAttribute("class").length() != 0)
-//				throw new IllegalStateException();
-//
-//			elt.setAttribute("class", getFillClassForDark());
-//			return;
-//		}
-
 		if (fill.matches("#[0-9A-Fa-f]{8}")) {
 			elt.setAttribute("fill", fill.substring(0, 7));
 			final double opacity = Integer.parseInt(fill.substring(7), 16) / 255.0;
@@ -897,7 +844,6 @@ public class SvgGraphics {
 
 	private final Map<String, String> images = new HashMap<String, String>();
 
-	
 	private void svgImageUnsecure(UImageSvg image, double x, double y) {
 		if (hidden == false) {
 			String svg = manageScale(image);
@@ -912,7 +858,6 @@ public class SvgGraphics {
 		ensureVisible(x + image.getData("width"), y + image.getData("height"));
 	}
 
-
 	public void svgImage(UImageSvg image, double x, double y) {
 		if (SecurityUtils.getSecurityProfile() == SecurityProfile.UNSECURE) {
 			svgImageUnsecure(image, x, y);
