@@ -34,6 +34,11 @@
  */
 package net.sourceforge.plantuml.ugraphic.color;
 
-public class HColorAutomagic extends HColorAbstract implements HColor {
+class HColorAutomagic extends HColor {
+
+	@Override
+	public HColor getAppropriateColor(HColor back) {
+		return back.opposite();
+	}
 
 }
