@@ -69,8 +69,8 @@ public class DriverEllipseEps implements UDriver<UEllipse, EpsGraphics> {
 			eps.epsEllipseShadow(x + width / 2, y + height / 2, width / 2, height / 2, shape.getDeltaShadow());
 		}
 
-		eps.setFillColor(mapper.toColor(param.getBackcolor()));
-		eps.setStrokeColor(mapper.toColor(param.getColor()));
+		eps.setFillColor(param.getBackcolor().toColor(mapper));
+		eps.setStrokeColor(param.getColor().toColor(mapper));
 		eps.setStrokeWidth(param.getStroke().getThickness(), param.getStroke().getDashVisible(), param.getStroke()
 				.getDashSpace());
 
