@@ -45,7 +45,7 @@ import net.sourceforge.plantuml.ugraphic.color.ColorMapper;
 public class DriverPixelG2d implements UDriver<UPixel, Graphics2D> {
 
 	public void draw(UPixel pixel, double x, double y, ColorMapper mapper, UParam param, Graphics2D g2d) {
-		g2d.setColor(mapper.toColor(param.getColor()));
+		g2d.setColor(param.getColor().toColor(mapper));
 		g2d.fillRect((int) x, (int) y, 1, 1);
 	}
 
