@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -34,38 +34,29 @@
  */
 package net.sourceforge.plantuml.ugraphic.hand;
 
-import net.sourceforge.plantuml.Url;
-import net.sourceforge.plantuml.graphic.StringBounder;
+import java.util.Random;
+
+import net.sourceforge.plantuml.graphic.UGraphicDelegator;
 import net.sourceforge.plantuml.posimo.DotPath;
-import net.sourceforge.plantuml.ugraphic.ColorMapper;
 import net.sourceforge.plantuml.ugraphic.UChange;
 import net.sourceforge.plantuml.ugraphic.UEllipse;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.ULine;
-import net.sourceforge.plantuml.ugraphic.UParam;
 import net.sourceforge.plantuml.ugraphic.UPath;
 import net.sourceforge.plantuml.ugraphic.UPolygon;
 import net.sourceforge.plantuml.ugraphic.URectangle;
 import net.sourceforge.plantuml.ugraphic.UShape;
+import net.sourceforge.plantuml.ugraphic.svg.UGraphicSvg;
 
-public class UGraphicHandwritten implements UGraphic {
+public class UGraphicHandwritten extends UGraphicDelegator implements UGraphic {
 
-	private final UGraphic ug;
-
-	public double dpiFactor() {
-		return ug.dpiFactor();
-	}
+	private final Random rnd = new Random(424242L);
 
 	public UGraphicHandwritten(UGraphic ug) {
-		this.ug = ug;
-	}
-
-	public StringBounder getStringBounder() {
-		return ug.getStringBounder();
-	}
-
-	public UParam getParam() {
-		return ug.getParam();
+		super(ug);
+		if (ug instanceof UGraphicSvg) {
+			((UGraphicSvg) ug).enlargeClip();
+		}
 	}
 
 	public void draw(UShape shape) {
@@ -84,62 +75,42 @@ public class UGraphicHandwritten implements UGraphic {
 		} else if (shape instanceof UPath) {
 			drawHand((UPath) shape);
 		} else {
-			ug.draw(shape);
+			getUg().draw(shape);
 		}
 	}
 
 	private void drawHand(UPath shape) {
-		final UPathHand uline = new UPathHand(shape);
-		ug.draw(uline.getHanddrawn());
+		final UPathHand uline = new UPathHand(shape, rnd);
+		getUg().draw(uline.getHanddrawn());
 	}
 
 	private void drawHand(DotPath shape) {
-		final UDotPathHand uline = new UDotPathHand(shape);
-		ug.draw(uline.getHanddrawn());
+		final UDotPathHand uline = new UDotPathHand(shape, rnd);
+		getUg().draw(uline.getHanddrawn());
 	}
 
 	private void drawHand(UPolygon shape) {
-		final UPolygonHand hand = new UPolygonHand(shape);
-		ug.draw(hand.getHanddrawn());
+		final UPolygonHand hand = new UPolygonHand(shape, rnd);
+		getUg().draw(hand.getHanddrawn());
 	}
 
 	private void drawHand(URectangle shape) {
-		final URectangleHand hand = new URectangleHand(shape);
-		ug.draw(hand.getHanddrawn());
+		final URectangleHand hand = new URectangleHand(shape, rnd);
+		getUg().draw(hand.getHanddrawn());
 	}
 
 	private void drawHand(ULine shape) {
-		final ULineHand uline = new ULineHand(shape);
-		ug.draw(uline.getHanddrawn());
+		final ULineHand uline = new ULineHand(shape, rnd);
+		getUg().draw(uline.getHanddrawn());
 	}
 
 	private void drawHand(UEllipse shape) {
-		final UEllipseHand uline = new UEllipseHand(shape);
-		ug.draw(uline.getHanddrawn());
+		final UEllipseHand uline = new UEllipseHand(shape, rnd);
+		getUg().draw(uline.getHanddrawn());
 	}
 
 	public UGraphic apply(UChange change) {
-		return new UGraphicHandwritten(ug.apply(change));
-	}
-
-	public ColorMapper getColorMapper() {
-		return ug.getColorMapper();
-	}
-
-	public void startUrl(Url url) {
-		ug.startUrl(url);
-	}
-
-	public void closeAction() {
-		ug.closeAction();
-	}
-
-	public void flushUg() {
-		ug.flushUg();
-	}
-
-	public boolean matchesProperty(String propertyName) {
-		return ug.matchesProperty(propertyName);
+		return new UGraphicHandwritten(getUg().apply(change));
 	}
 
 }
