@@ -67,7 +67,7 @@ public class DriverLineHtml5 implements UDriver<ULine, Html5Drawer> {
 			y2 = line.y2;
 		}
 
-		final String color = param.getColor() == null ? null : mapper.toRGB(param.getColor());
+		final String color = param.getColor() == null ? null : param.getColor().toRGB(mapper);
 		html.setStrokeColor(color);
 
 		html.htmlLine(x, y, x2, y2, 0);
