@@ -85,7 +85,7 @@ public class CommandSpot extends SingleLineCommand2<WireDiagram> {
 		final String stringColor = arg.get("COLOR", 0);
 		HColor color = null;
 		if (stringColor != null)
-			color = HColorSet.instance().getColor(diagram.getSkinParam().getThemeStyle(), stringColor);
+			color = HColorSet.instance().getColor(stringColor);
 
 		final String x = arg.get("X", 0);
 		final String y = arg.get("Y", 0);
